from matplotlib.colors import LinearSegmentedColormap

UV_CMAP = LinearSegmentedColormap.from_list(
    name="UV",
    colors=["black", "#B015A5"]  # A midpoint between neon violet pink and deep violet
)